#include <slope/solvers/hybrid_cd.h>

namespace slope {

} // namespace slope
